==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { MultiColumnComboBoxTextChangedEventArgsDescription } from "./MultiColumnComboBoxTextChangedEventArgsDescription";
/**
 * @hidden
 */
var MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata, _super);
    function MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.b = function (a) {
        if (MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a == null) {
            MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.c(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a);
    };
    MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.d = function (a) {
        MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.b(a);
        a.u("MultiColumnComboBoxTextChangedEventArgs", function () { return new MultiColumnComboBoxTextChangedEventArgsDescription(); });
        a.t("MultiColumnComboBoxTextChangedEventArgs", MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a);
    };
    MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.$t = markType(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata, 'MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata');
    MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a = null;
    return MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata;
}(Base));
export { MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { MultiColumnComboBoxTextChangedEventArgsDescription } from "./MultiColumnComboBoxTextChangedEventArgsDescription";
/**
 * @hidden
 */
var MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata, _super);
    function MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.b = function (a) {
        if (MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a == null) {
            MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.c(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a);
    };
    MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.d = function (a) {
        MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.b(a);
        a.aa("MultiColumnComboBoxTextChangedEventArgs", function () { return new MultiColumnComboBoxTextChangedEventArgsDescription(); });
        a.z("MultiColumnComboBoxTextChangedEventArgs", MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a);
    };
    MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.$t = markType(MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata, 'MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata');
    MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata.a = null;
    return MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata;
}(Base));
export { MultiColumnComboBoxTextChangedEventArgsDescriptionMetadata };
